class DeprecatedLibrary(Exception):
	def __init__(self, library, funName, line):
		self.library = library
		self.funName = funName
		self.line = line
		self.message = f"Il sito è cambiato, di conseguenza la libreria {library} è DEPRECATA. -> [{library}.{funName} - {line}]"
		super().__init__(self.message)


import os, re

# Carica le librerie ######################################################################################

this_file = os.path.abspath(__file__)
this_dir = os.path.dirname(this_file)
base_path = os.path.join(this_dir, "libraries")


for job in os.listdir(base_path):

	# import_module(f"jobs.{myjob}")
	module = __import__(f"libraries.{job}", globals(),locals(), fromlist=["*"], level=1)

	for k in dir(module):
		locals()[k] = getattr(module, k)

# from error import * # Importa le Exception globali

############################################################################################################



# Funzione di 'cast'

def Anime(link):
	# lista pattern
	anime_world = re.compile(r"www\.animeworld\.tv")




	if anime_world.search(link) is not None:
		return AnimeWorld(link)


import setuptools

setuptools.setup(
    name="animeit", # Replace with your own username
    version="0.0.1",
    author="MainKronos",
    author_email="lorenzo.chesi@live.it",
    description="AnimeIT-API",
    long_description="Libreria per accedere facilmente ai dati di vari siti streaming di anime sub ita",
    long_description_content_type="text/markdown",
    url="https://github.com/MainKronos/AnimeIT-API",
    packages=setuptools.find_packages(),
    install_requires=['requests', 'youtube_dl', 'beautifulsoup4'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)


from .error import * # Importa le Exception globali

import inspect, os

def HealthCheck(fun): # Controlla se la libreria è deprecata
	def wrapper(*args, **kwargs):
		try:
			return fun(*args, **kwargs)
		except AttributeError:
			frame = inspect.trace()[-1]
			funName = frame[3]
			errLine = frame[2]
			library = frame[1].split(os.sep)[-2]
			raise DeprecatedLibrary(library, funName, errLine)
	return wrapper